@@ -36,16 +36,19 @@ end
     @testset "compilation database" begin
         mod = @eval module $(gensym())
             @noinline inner(x) = x+1
-            function outer(x)
-                return inner(x)
+            function outer(x, sym)
+                if sym == :a
+                    return inner(x)
+                end
+                return x
             end
         end
 
-        job, _ = Native.create_job(mod.outer, (Int,))
+        job, _ = Native.create_job(mod.outer, (Int, Symbol))
         JuliaContext() do ctx
-            ir, meta = GPUCompiler.compile(:llvm, job)
+            ir, meta = GPUCompiler.compile(:llvm, job; validate=false)
 
-            meth = only(methods(mod.outer, (Int,)))
+            meth = only(methods(mod.outer, (Int, Symbol)))
 
             mis = filter(mi->mi.def == meth, keys(meta.compiled))
             @test length(mis) == 1
@@ -53,6 +56,19 @@ end
             other_mis = filter(mi->mi.def != meth, keys(meta.compiled))
             @test length(other_mis) == 1
             @test only(other_mis).def in methods(mod.inner)
+
+            if VERSION >= v"1.12"
+                @test length(meta.gv_to_value) == 1
+                for (k, v) in meta.gv_to_value
+                    @test v != C_NULL
+                end
+            end
+            # TODO: Global values get privatized, so we can't find them by name anymore.
+            # %.not = icmp eq ptr %"sym::Symbol", inttoptr (i64 140096668482288 to ptr), !dbg !38
+            # for (name, v) in meta.gv_to_value
+            #     gv = globals(ir)[name]
+            #     @test LLVM.initializer(gv) === v
+            # end
         end
     end
 
@@ -643,7 +659,12 @@ end
         end
 
         Base.Experimental.@MethodTable method_table
-        Base.Experimental.@overlay method_table @noinline Core.throw_inexacterror(f::Symbol, ::Type{T}, val) where {T} = return
+        # @consistent_overlay (Julia 1.11+) is needed for the compiler to optimize through the overlay
+        @static if VERSION >= v"1.11-"
+            Base.Experimental.@consistent_overlay method_table @noinline Core.throw_inexacterror(f::Symbol, ::Type{T}, val) where {T} = return
+        else
+            Base.Experimental.@overlay method_table @noinline Core.throw_inexacterror(f::Symbol, ::Type{T}, val) where {T} = return
+        end
     end
 
     @test @filecheck begin
